==> hubzero-submit-monitors_3.9.1-1+deb12.tar.gz: source/manageIdentitiesQ.py <==
#!/usr/bin/env python3
#
# @package      hubzero-submit-monitors
# @file         manageIdentitiesQ.py
# @copyright    Copyright (c) 2004-2020 The Regents of the University of California.
# @license      http://opensource.org/licenses/MIT MIT
#
# Copyright (c) 2004-2020 The Regents of the University of California.
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
#
# HUBzero is a registered trademark of The Regents of the University of California.
#
# ----------------------------------------------------------------------
#  manageIdentitiesQ.py
#
#  script which queries manageIdentities.py for a user identity
#
import os
import sys
import logging

from hubzero.submit.DaemonsInfo           import DaemonsInfo
from hubzero.submit.RemoteIdentityManager import RemoteIdentityManager

CONFIGURATIONDIRECTORY   = os.path.join(os.sep,'etc','submit')
DAEMONSCONFIGURATIONFILE = 'daemons.conf'

APPLICATIONLOGGER = logging.getLogger('') 

def openLogger():
   class EmptyFilter(logging.Filter):
      """
      This is a filter which rejects empty messages

      """

      def filter(self,record):
         if record.getMessage() == "":
            emptyRecord = True
         else:
            emptyRecord = False

         return(not emptyRecord)

   APPLICATIONLOGGER.setLevel(logging.DEBUG)

   logHandler = logging.StreamHandler()

   emptyFilter = EmptyFilter()
   logHandler.addFilter(emptyFilter)

   logFormatter = logging.Formatter('%(asctime)s %(message)s','[%a %b %d %H:%M:%S %Y]')
   logHandler.setFormatter(logFormatter)
   APPLICATIONLOGGER.addHandler(logHandler)


def manageIdentitiesQ(listenURI):
   """user identity Query"""
   identityName = sys.argv[1]
   hubUserName  = sys.argv[2]

   remoteIdentityManager = RemoteIdentityManager(listenURI)

   identityPaths = remoteIdentityManager.queryUserIdentities(identityName,hubUserName)

   print(identityName,hubUserName,identityPaths)


if __name__ == '__main__':
   openLogger()

   configFilePath = os.path.join(CONFIGURATIONDIRECTORY,DAEMONSCONFIGURATIONFILE)
   daemonsInfo    = DaemonsInfo(configFilePath)
   listenURI      = daemonsInfo.getDaemonListenURI('identitiesManager','tcp')

   manageIdentitiesQ(listenURI)

==> hubzero-submit-monitors_3.10.1-1+deb12.tar.gz: source/manageIdentitiesQ.py <==
#!/usr/bin/env python3
#
# @package      hubzero-submit-monitors
# @file         manageIdentitiesQ.py
# @copyright    Copyright (c) 2004-2020 The Regents of the University of California.
# @license      http://opensource.org/licenses/MIT MIT
#
# Copyright (c) 2004-2020 The Regents of the University of California.
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
#
# HUBzero is a registered trademark of The Regents of the University of California.
#
# ----------------------------------------------------------------------
#  manageIdentitiesQ.py
#
#  script which queries manageIdentities.py for a user identity
#
import os
import sys
import logging

from hubzero.submit.ApplicationUtilities  import ApplicationUtilities as ApplicationUtilities
from hubzero.submit.DaemonsInfo           import DaemonsInfo
from hubzero.submit.RemoteIdentityManager import RemoteIdentityManager

SUBMITUTILITYLOGLEVEL = "ERROR"

DAEMONSDIRECTORY         = os.path.join(os.sep,"etc","submit")
DAEMONSCONFIGURATIONFILE = 'daemons.conf'

def manageIdentitiesQ(listenURI):
   """user identity Query"""
   identityName = sys.argv[1]
   hubUserName  = sys.argv[2]

   remoteIdentityManager = RemoteIdentityManager(listenURI)

   identityPaths = remoteIdentityManager.queryUserIdentities(identityName,hubUserName)

   print(identityName,hubUserName,identityPaths)


if __name__ == '__main__':
   submitUtilityLogLevel    = os.getenv("SUBMITUTILITYLOGLEVEL",SUBMITUTILITYLOGLEVEL)
   daemonsDirectory         = os.getenv("DAEMONSDIRECTORY",DAEMONSDIRECTORY)
   daemonsConfigurationFile = os.getenv("DAEMONSCONFIGURATIONFILE",DAEMONSCONFIGURATIONFILE)

   applicationUtilities = ApplicationUtilities(SUBMITUTILITYLOGLEVEL)
   applicationUtilities.openStreamLogger(sys.stderr,
                                         submitUtilityLogLevel)

   configFilePath = os.path.join(daemonsDirectory,daemonsConfigurationFile)
   daemonsInfo    = DaemonsInfo(configFilePath)
   listenURI      = daemonsInfo.getDaemonListenURI('identitiesManager','tcp')

   manageIdentitiesQ(listenURI)
